@@ -1,27 +1,9 @@
-/*
- * Borrowed from KDevelop (kdevplatform/language/interfaces/abbreviations.cpp)
- *
- * Copyright 2014 Sven Brauch <svenbrauch@gmail.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+// SPDX-FileCopyrightText: 2014 Sven Brauch <svenbrauch@gmail.com>
+//
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "abbreviations.h"
 
-#include <QStringList>
 #include <QVarLengthArray>
 
 namespace
@@ -30,12 +12,22 @@ constexpr const std::size_t offsetsSize = 32;
 constexpr const int maxDepth = 128;
 
 // Taken and adapted for kdevelop from katecompletionmodel.cpp
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 bool matchesAbbreviationHelper(const QStringRef &word,
                                const QStringRef &typed,
                                const QVarLengthArray<int, offsetsSize> &offsets,
                                int &depth,
                                int atWord = -1,
                                int i = 0)
+#else
+bool matchesAbbreviationHelper(const QStringView &word,
+                               const QStringView &typed,
+                               const QVarLengthArray<int, offsetsSize> &offsets,
+                               int &depth,
+                               int atWord = -1,
+                               int i = 0)
+
+#endif
 {
     int atLetter = 1;
     for (; i < typed.size(); i++) {
@@ -81,8 +73,11 @@ bool matchesAbbreviationHelper(const QStringRef &word,
 }
 
 }
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 bool PlasmaPass::matchesAbbreviation(const QStringRef &word, const QStringRef &typed)
+#else
+bool PlasmaPass::matchesAbbreviation(const QStringView &word, const QStringView &typed)
+#endif
 {
     // A mismatch is very likely for random even for the first letter,
     // thus this optimization makes sense.
@@ -121,8 +116,11 @@ bool PlasmaPass::matchesAbbreviation(const QStringRef &word, const QStringRef &t
     int depth = 0;
     return matchesAbbreviationHelper(word, typed, offsets, depth);
 }
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 bool PlasmaPass::matchesPath(const QStringRef &path, const QStringRef &typed)
+#else
+bool PlasmaPass::matchesPath(const QStringView &path, const QStringView &typed)
+#endif
 {
     int consumed = 0;
     int pos = 0;
@@ -136,8 +134,11 @@ bool PlasmaPass::matchesPath(const QStringRef &path, const QStringRef &typed)
     }
     return consumed == typed.size();
 }
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 int PlasmaPass::matchPathFilter(const QVector<QStringRef> &toFilter, const QVector<QStringRef> &text)
+#else
+int PlasmaPass::matchPathFilter(const QVector<QStringView> &toFilter, const QVector<QStringView> &text)
+#endif
 {
     enum PathFilterMatchQuality {
         NoMatch = -1,
