@@ -16,7 +16,11 @@ class QDBusPendingCallWatcher;
 class KJob;
 class QMimeData;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 namespace Plasma
+#else
+namespace Plasma5Support
+#endif
 {
 class DataEngineConsumer;
 }
@@ -78,8 +82,11 @@ private:
 
     void removePasswordFromClipboard(const QString &password);
     static void clearClipboard();
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     std::unique_ptr<Plasma::DataEngineConsumer> mEngineConsumer;
+#else
+    std::unique_ptr<Plasma5Support::DataEngineConsumer> mEngineConsumer;
+#endif
     QString mPath;
     QString mError;
     QString mSecret;
